python_runtime_files

Function python_runtime_files 

pub fn python_runtime_files() -> Vec<(&'static str, &'static str)>
Returns static runtime Python files to be written alongside generated code. These files implement the base client, engine process manager, protocol, and errors.