Module writer

Module writer 

File writing utilities for generated code.

Functions

write_js_code
Write generated JavaScript + TypeScript declaration code to the output directory.
write_python_code
Write generated Python code to files in the output directory with organized structure.
write_rust_code
Write generated code to files in the output directory.